@@ -61,17 +61,17 @@ def generate_workplace_contact_network(num_cohorts=1, num_nodes_per_cohort=100,
 
         cohortStartIdx = cohortFinalIdx + 1
         cohortFinalIdx = cohortStartIdx + cohortNetwork.number_of_nodes() - 1
-        cohorts_indices['c'+str(c)] = range(cohortStartIdx, cohortFinalIdx)
+        cohorts_indices['c'+str(c)] = list(range(cohortStartIdx, cohortFinalIdx))
 
         for team, indices in teams_indices.items():
             if('c'+str(c) in team):
                 teams_indices[team] = [idx+cohortStartIdx for idx in indices]
 
-        for i in range(cohortNetwork.number_of_nodes()):
+        for i in list(range(cohortNetwork.number_of_nodes())):
             i_intraCohortDegree = cohortNetwork.degree[i]
             i_interCohortDegree = int( ((1/(1-pct_contacts_intercohort))*i_intraCohortDegree)-i_intraCohortDegree )
-            for d in range(i_interCohortDegree):
-                j = numpy.random.choice(range(0, cohortStartIdx)+range(cohortFinalIdx+1, N))
+            for d in list(range(i_interCohortDegree)):
+                j = numpy.random.choice(list(range(0, cohortStartIdx))+list(range(cohortFinalIdx+1, N)))
                 workplaceNetwork.add_edge(i, j)
 
     return workplaceNetwork, cohorts_indices, teams_indices
